# zakhar_pycore

Base python package for the Zakhar project

- Part of the [Zakhar's Brain](https://github.com/an-dr/zakhar_brain)
- Part of the [Zakhar Project](https://github.com/an-dr/zakhar)

## Installation

From pypi.org:

```bash
pip install zakhar-pycore
```

From GitHub:

``` bash
pip install git+https://github.com/an-dr/zakhar_pycore
```

From GitHub for a specific branch:

```bash
pip install git+https://github.com/an-dr/zakhar_pycore@branch_name
```
